@@ -987,6 +987,14 @@ onOK <- function(){
       commande.hcpc<-paste(nom.res,'.hcpc', '<-HCPC(', nom.res, ' ,nb.clust=', Rmeth, ',consol=', Rconsolid,',min=', Rminhcpc,',max=',Rmaxhcpc,',graph=', Rgraphhcpc, ')', sep="")
     justDoIt(commande.hcpc)
     logger(commande.hcpc)      
+	if ((Axe[1]!=1)||(Axe[2]!=2)){
+	  command.plothcpc <- paste('plot(',nom.res,'.hcpc, axes=c(', paste(Axe, collapse=", "), '),new.plot=TRUE)',sep="")
+      justDoIt(command.plothcpc)
+      logger(command.plothcpc)
+	  command.plothcpc2 <- paste('plot(',nom.res,'.hcpc, choice="map",axes=c(', paste(Axe, collapse=", "), '),draw.tree=FALSE, new.plot=TRUE)',sep="")
+      justDoIt(command.plothcpc2)
+      logger(command.plothcpc2)
+	}
       if(Rreshcpc==TRUE){
         doItAndPrint(paste(nom.res,'.hcpc$data.clust[,ncol(res.hcpc$data.clust),drop=F]', sep=""))
         doItAndPrint(paste(nom.res,'.hcpc$desc.var', sep=""))
@@ -1009,6 +1017,7 @@ onOK <- function(){
       if (!is.null(RXlimInd)) commande.plotInd <- paste(commande.plotInd,', xlim=c(', paste(RXlimInd, collapse=", "), ')', sep="")
       if (!is.null(RYlimInd)) commande.plotInd <- paste(commande.plotInd,', ylim=c(', paste(RYlimInd, collapse=", "), ')', sep="")
       commande.plotInd <- paste(commande.plotInd,')', sep="")
+	  commande.plotInd <- paste0("print(",commande.plotInd,")")
       justDoIt(commande.plotInd)
       logger(commande.plotInd)
     }}
@@ -1016,26 +1025,28 @@ onOK <- function(){
     if((Vchoix)&(length(which(ls(envir = .GlobalEnv, all.names = TRUE)==nom.res))>0)){
     if (get(nom.res)$eig[1,2]!=100) {
       if (is.null(Vinvis)) Vinvis <- ""
-	  if (Vinvis!="") commande.plotInd<-paste('plot.MCA(', nom.res, ', axes=c(', paste(Axe, collapse=", "), '), new.plot=TRUE, choix="var", col.var="',Vcol.var,'", col.quali.sup="',Vcol.quali.sup,'", label=c("', paste(Vlabel, collapse='", "'), '"), invisible=c("', paste(Vinvis, collapse='", "'), '")', sep="")
-      else commande.plotInd<-paste('plot.MCA(', nom.res, ', axes=c(', paste(Axe, collapse=", "), '), new.plot=TRUE, choix="var", col.var="',Vcol.var,'", col.quali.sup="',Vcol.quali.sup,'", label=c("', paste(Vlabel, collapse='", "'),'")', sep="")
+	  if (Vinvis!="") commande.plotV<-paste('plot.MCA(', nom.res, ', axes=c(', paste(Axe, collapse=", "), '), new.plot=TRUE, choix="var", col.var="',Vcol.var,'", col.quali.sup="',Vcol.quali.sup,'", label=c("', paste(Vlabel, collapse='", "'), '"), invisible=c("', paste(Vinvis, collapse='", "'), '")', sep="")
+      else commande.plotV<-paste('plot.MCA(', nom.res, ', axes=c(', paste(Axe, collapse=", "), '), new.plot=TRUE, choix="var", col.var="',Vcol.var,'", col.quali.sup="',Vcol.quali.sup,'", label=c("', paste(Vlabel, collapse='", "'),'")', sep="")
 	  if (!is.null(VTitle)) {
-        if (VTitle !=" ") commande.plotInd <- paste(commande.plotInd,', title="', VTitle,'"', sep="")
+        if (VTitle !=" ") commande.plotV <- paste(commande.plotV,', title="', VTitle,'"', sep="")
       }
-      commande.plotInd <- paste(commande.plotInd,')', sep="")
-      justDoIt(commande.plotInd) 
-      logger(commande.plotInd)
+      commande.plotV <- paste(commande.plotV,')', sep="")
+	  commande.plotV <- paste0("print(",commande.plotV,")")
+      justDoIt(commande.plotV) 
+      logger(commande.plotV)
     }}
 
     if((Wchoix)&(length(which(ls(envir = .GlobalEnv, all.names = TRUE)==nom.res))>0)){
     if (get(nom.res)$eig[1,2]!=100) {
-      commande.plotInd<-paste('plot.MCA(', nom.res, ', axes=c(', paste(Axe, collapse=", "), '), new.plot=TRUE, choix="quanti.sup", col.quanti.sup="',Wcol.quanti.sup,'"',', label=c("', paste(Wlabel, collapse='", "'),'")', sep="")
+      commande.plotW<-paste('plot.MCA(', nom.res, ', axes=c(', paste(Axe, collapse=", "), '), new.plot=TRUE, choix="quanti.sup", col.quanti.sup="',Wcol.quanti.sup,'"',', label=c("', paste(Wlabel, collapse='", "'),'")', sep="")
       if (!is.null(WTitle)) {
-        if (WTitle !=" ") commande.plotInd <- paste(commande.plotInd,', title="', WTitle,'"', sep="")
+        if (WTitle !=" ") commande.plotW <- paste(commande.plotW,', title="', WTitle,'"', sep="")
       }
-#      if ("quanti.sup"%in%Wlabel) commande.plotInd <- paste(commande.plotInd, ',label=c("quanti.sup")',sep='') 
-      commande.plotInd <- paste(commande.plotInd,')', sep="")
-      justDoIt(commande.plotInd) 
-      logger(commande.plotInd)
+#      if ("quanti.sup"%in%Wlabel) commande.plotW <- paste(commande.plotW, ',label=c("quanti.sup")',sep='') 
+      commande.plotW <- paste(commande.plotW,')', sep="")
+	  commande.plotW <- paste0("print(",commande.plotW,")")
+      justDoIt(commande.plotW) 
+      logger(commande.plotW)
     }}
 
     # gestion de l'dition de certains resultats
